clear
clear matrix
log using "oil_hr.log", replace

*************************************************************************
*************************************************************************
* File to run models and calculate quantities of interest for the paper *
************ "A Political Economy of Human Rights:  *********************
****************** Oil and State Incentives to Repress" *****************                                                                
*************************************************************************
* Paper authors: DeMeritt & Young										*
* Created by: Jacqueline H.R. DeMeritt									*
* Created on: 7 August 2010												*                                               	                
* Last edited on: 25 April 2011											*	
* Last edited by: JHRD													*                 
*************************************************************************
*************************************************************************

set mem 1000m
set matsize 1000
*use "/Users/demeritt/Desktop/research/DeMeritt-Young/oil_hr.dta"
use "/Users/demeritt/Desktop/research/DeMeritt-Young/JCR R&R stuff/oil_hr.dta"
set seed 11232007
set more off

* NOTE: CIRI physint and all component parts are flipped so that higher 
* values indicate *decreasing* govt respect for rights, or increasing abuse.

* Oil is FL's dummy for oil exporters
* oil_gas_rentPOP is Ross's oil measure
* ln_oil_gas_rentPOP is the natural log of that measure +.001.

***************************
***************************
* DV = CIRI Physint Index *
***************************
***************************

*************************
* run model with oil = Fearon & Laitin oil dummy
*************************
ologit physintflip Oil polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, nolog cluster(ccode)

*add interaction (robustness check)
ologit physintflip Oil polity2 gdpenl demxgdp jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, nolog cluster(ccode)

*************************
* run model with oil = Ross oil & fuel rents per capita
*************************
ologit physintflip oil_gas_rentPOP polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, nolog cluster(ccode)

*add interaction (robustness check)
ologit physintflip oil_gas_rentPOP polity2 gdpenl demxgdp jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, nolog cluster(ccode)

*************************
* run model with oil = ln(Ross oil & fuel rents per capita)
*************************
ologit physintflip ln_oil_gas_rentPOP polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, nolog cluster(ccode)

*add interaction (robustness check)
ologit physintflip ln_oil_gas_rentPOP polity2 gdpenl demxgdp jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, nolog cluster(ccode)

*****************
*****************
* DV = PTS (AI) *
*****************
*****************

*************************
* run model with oil = Fearon & Laitin oil dummy
*************************
ologit pts_a Oil polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag, nolog cluster(ccode)

*add interaction (robustness check)
ologit pts_a Oil polity2 gdpenl demxgdp jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag, nolog cluster(ccode)


*************************
* run model with oil = Ross oil & fuel rents per capita
*************************
ologit pts_a oil_gas_rentPOP polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag, nolog cluster(ccode)

*add interaction (robustness check)
ologit pts_a oil_gas_rentPOP polity2 gdpenl demxgdp jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag, nolog cluster(ccode)


*************************
* run model with oil = ln(Ross oil & fuel rents per capita)
*************************
ologit pts_a ln_oil_gas_rentPOP polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag, nolog cluster(ccode)

*add interaction (robustness check)
ologit pts_a ln_oil_gas_rentPOP polity2 gdpenl demxgdp jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag, nolog cluster(ccode)

******************
******************
* DV = PTS (DoS) *
******************
******************

*************************
* run model with oil = Fearon & Laitin oil dummy
*************************
ologit pts_s Oil polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag2, nolog cluster(ccode)

*add interaction (robustness check)
ologit pts_s Oil polity2 gdpenl demxgdp jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag2, nolog cluster(ccode)


*************************
* run model with oil = Ross oil & fuel rents per capita
*************************
ologit pts_s oil_gas_rentPOP polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag2, nolog cluster(ccode)

*add interaction (robustness check)
ologit pts_s oil_gas_rentPOP polity2 gdpenl demxgdp jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag2, nolog cluster(ccode)


*************************
* run model with oil = ln(Ross oil & fuel rents per capita)
*************************
ologit pts_s ln_oil_gas_rentPOP polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag2, nolog cluster(ccode)

*add interaction (robustness check)
ologit pts_s ln_oil_gas_rentPOP polity2 gdpenl demxgdp jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag2, nolog cluster(ccode)

log close
log using "oil_hr_substantive.log", replace

***********************
***********************
* SUBSTANTIVE EFFECTS *
***********************
***********************
quietly{
drop b*
estsimp ologit physintflip Oil polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, nolog cluster(ccode)
setx polity2 3 gdpenl mean jobinsecurity_bdm mean lpop mean diss_lag mean cowwarl 0 lmtnest mean physint_lag 5 
}
** EFFECTS OF BECOMING AN OIL EXPORTER (FL Oil 0->1), all else equal (at means and medians):
simqi, fd(pr) changex(Oil 0 1)

quietly{
drop b*
estsimp ologit physintflip oil_gas_rentPOP polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, nolog cluster(ccode)
setx polity2 3 gdpenl mean jobinsecurity_bdm mean lpop mean diss_lag mean cowwarl 0 lmtnest mean physint_lag 5 
}
** BASELINE PR (all vars at means or modes):
setx oil_gas_rentPOP 320.3041 
simqi

** EFFECTS OF A MIN-MAX INCREASE IN OIL INCOME PER CAPITA (Ross's oil measure):
simqi, fd(pr) changex(oil_gas_rentPOP min max)

** EFFECTS OF INCREASED OIL/CAPITA +1sd above mean:
simqi, fd(pr) changex(oil_gas_rentPOP 320.3041 320.3031+1336.275)

** EFFECTS OF INCREASED OIL/CAPITA +2sd above mean:
simqi, fd(pr) changex(oil_gas_rentPOP 320.3041 320.3031+1336.275+1336.275)

** EFFECTS OF INCREASED OIL/CAPITA +3sd above mean:
simqi, fd(pr) changex(oil_gas_rentPOP 320.3041 4329.1281)

** EFFECTS OF INCREASED OIL/CAPITA +5sd above mean:
simqi, fd(pr) changex(oil_gas_rentPOP 320.3041 7001.6781)

*************** EFFECTS ON CIRI COMPONENT PARTS ***************
*** Disappearances ***
quietly{
drop b*
estsimp ologit disappear Oil polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest disappear_lag, cluster(ccode) nolog
setx polity2 3 gdpenl mean jobinsecurity_bdm mean lpop mean diss_lag mean cowwarl 0 lmtnest mean disappear_lag 0 
}
** EFFECTS OF BECOMING AN OIL EXPORTER:
simqi, fd(pr) changex(Oil 0 1)

quietly{
drop b*
estsimp ologit disappear oil_gas_rentPOP polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest disappear_lag, cluster(ccode) nolog
setx polity2 3 gdpenl mean jobinsecurity_bdm mean lpop mean diss_lag mean cowwarl 0 lmtnest mean disappear_lag 0 
}
**EFFECTS OF A MIN-MAX INCREASE IN OIL INCOME PER CAPITA
simqi, fd(pr) changex(oil_gas_rentPOP min max)

	
*** Killing ***
quietly{
drop b*
estsimp ologit kill Oil polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest kill_lag, cluster(ccode) nolog
setx polity2 3 gdpenl mean jobinsecurity_bdm mean lpop mean diss_lag mean cowwarl 0 lmtnest mean kill_lag 0 
}
** EFFECTS OF BECOMING AN OIL EXPORTER:
simqi, fd(pr) changex(Oil 0 1)

quietly{
drop b*
estsimp ologit kill oil_gas_rentPOP polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest kill_lag, cluster(ccode) nolog
setx polity2 3 gdpenl mean jobinsecurity_bdm mean lpop mean diss_lag mean cowwarl 0 lmtnest mean kill_lag 0 
}
**EFFECTS OF A MIN-MAX INCREASE IN OIL INCOME PER CAPITA
simqi, fd(pr) changex(oil_gas_rentPOP min max)


*** Imprisonment ***
quietly{
drop b*
estsimp ologit imprison Oil polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest imprison_lag, cluster(ccode) nolog
setx polity2 3 gdpenl mean jobinsecurity_bdm mean lpop mean diss_lag mean cowwarl 0 lmtnest mean imprison_lag 0 
}
** EFFECTS OF BECOMING AN OIL EXPORTER:
simqi, fd(pr) changex(Oil 0 1)

quietly{
drop b*
estsimp ologit imprison oil_gas_rentPOP polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest imprison_lag, cluster(ccode) nolog
setx polity2 3 gdpenl mean jobinsecurity_bdm mean lpop mean diss_lag mean cowwarl 0 lmtnest mean imprison_lag 0 
}
**EFFECTS OF A MIN-MAX INCREASE IN OIL INCOME PER CAPITA
simqi, fd(pr) changex(oil_gas_rentPOP min max)


*** Torture ***
quietly{
drop b*
*Need to drop cowwarl because it predicts success (0) perfectly here:
*estsimp logit torture Oil polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest torture_lag, cluster(ccode) nolog
*setx polity2 3 gdpenl mean jobinsecurity_bdm mean lpop mean diss_lag mean cowwarl 0 lmtnest mean torture_lag 2 
estsimp logit torture_bin Oil polity2 gdpenl jobinsecurity_bdm lpop diss_lag lmtnest tort_bin_lag, cluster(ccode) nolog
setx polity2 3 gdpenl mean jobinsecurity_bdm mean lpop mean diss_lag mean lmtnest mean tort_bin_lag 1 
}
** EFFECTS OF BECOMING AN OIL EXPORTER:
simqi, fd(pr) changex(Oil 0 1)

quietly{
drop b*
*Need to drop cowwarl because it predicts success (0) perfectly here:
*estsimp logit torture oil_gas_rentPOP polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest torture_lag, cluster(ccode) nolog
*setx polity2 3 gdpenl mean jobinsecurity_bdm mean lpop mean diss_lag mean cowwarl 0 lmtnest mean torture_lag 2
estsimp logit torture_bin oil_gas_rentPOP polity2 gdpenl jobinsecurity_bdm lpop diss_lag lmtnest tort_bin_lag, cluster(ccode) nolog
setx polity2 3 gdpenl mean jobinsecurity_bdm mean lpop mean diss_lag mean lmtnest mean tort_bin_lag 1
}
**EFFECTS OF A MIN-MAX INCREASE IN OIL INCOME PER CAPITA
simqi, fd(pr) changex(oil_gas_rentPOP min max)

log close
log using "oil_hr_supplement.log", replace

********************************
********************************
* INFORMATION FOR ONLINE SUPPLEMENT
********************************
********************************
set seed 11232007

*** Distributions on DVs ***

hist physintflip, discrete scheme(sj) xtitle("CIRI Physical Integrity Index (flipped)")
graph export hist_ciri.pdf, replace

hist pts_a, discrete scheme(sj) xtitle("Political Terror Scale (AI)")
graph export hist_ptsa.pdf, replace

hist pts_s, discrete scheme(sj) xtitle("Political Terror Scale (DOS)")
graph export hist_ptss.pdf, replace

*** Models via OLS ***

* CIRI
reg physintflip Oil polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode)
reg physintflip oil_gas_rentPOP polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode)

* PTS_A
reg pts_a Oil polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag, cluster(ccode)
reg pts_a oil_gas_rentPOP polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag, cluster(ccode)

* PTS_S
reg pts_s Oil polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag2, cluster(ccode)
reg pts_s oil_gas_rentPOP polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag2, cluster(ccode)

*** CIRI Component Rights (ologit) ***

* Disappearances
ologit disappear Oil polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest disappear_lag, cluster(ccode) nolog
ologit disappear oil_gas_rentPOP polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest disappear_lag, cluster(ccode) nolog

* Killing
ologit kill Oil polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest kill_lag, cluster(ccode) nolog
ologit kill oil_gas_rentPOP polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest kill_lag, cluster(ccode) nolog

* Imprisonment
ologit imprison Oil polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest imprison_lag, cluster(ccode) nolog
ologit imprison oil_gas_rentPOP polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest imprison_lag, cluster(ccode) nolog

* Torture
ologit torture Oil polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest torture_lag, cluster(ccode) nolog
ologit torture oil_gas_rentPOP polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest torture_lag, cluster(ccode) nolog

********************************
* RECONCEPTUALIZE DEMOCRACY
********************************

*** Binary decomposition of POLITY Democ-Autoc ***
xi: ologit physintflip Oil gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag i.polity2, cluster(ccode)
xi: ologit physintflip oil_gas_rentPOP gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag i.polity2, cluster(ccode)
xi: ologit pts_a Oil gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag i.polity2, cluster(ccode)
xi: ologit pts_a oil_gas_rentPOP gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag i.polity2, cluster(ccode)
xi: ologit pts_s Oil gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag2 i.polity2, cluster(ccode)
xi: ologit pts_s oil_gas_rentPOP gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag2 i.polity2, cluster(ccode)

*** Collapsed (linear) scale of POLITY Democ-Autoc ***
*NOTE: Each linear scale is derived from the coefficients on the corresponding binary decomposition (above). 
quietly{
gen polity_linear1=.
replace polity_linear1=1 if polity2<-7
replace polity_linear1=2 if polity2==-7
replace polity_linear1=3 if polity2>-7 & polity2<-4
replace polity_linear1=4 if polity2>-5 & polity2<-1
replace polity_linear1=5 if polity2>-2 & polity2<1
replace polity_linear1=6 if polity2>0 & polity2<3
replace polity_linear1=7 if polity2==3
replace polity_linear1=8 if polity2==4
replace polity_linear1=9 if polity2==5
replace polity_linear1=10 if polity2>5
tab polity_linear1
}

quietly{
gen polity_linear2=.
replace polity_linear2=1 if polity2<-8
replace polity_linear2=2 if polity2>-9 & polity2<-6
replace polity_linear2=3 if polity2==-6
replace polity_linear2=4 if polity2>-6 & polity2<0
replace polity_linear2=5 if polity2==0
replace polity_linear2=6 if polity2>0 & polity2<3
replace polity_linear2=7 if polity2==3
replace polity_linear2=8 if polity2>3
tab polity_linear2
}

quietly{
gen polity_linear3=.
replace polity_linear3=1 if polity2<0
replace polity_linear3=2 if polity2==0
replace polity_linear3=3 if polity2>0 & polity2<3
replace polity_linear3=4 if polity2==3
replace polity_linear3=5 if polity2>3
tab polity_linear3
}

quietly{
gen polity_linear4=.
replace polity_linear4=1 if polity2<0
replace polity_linear4=2 if polity2==0
replace polity_linear4=3 if polity2>0 & polity2<3
replace polity_linear4=4 if polity2==3
replace polity_linear4=5 if polity2>3
tab polity_linear4
}

quietly{
gen polity_linear5=.
replace polity_linear5=1 if polity2<-5
replace polity_linear5=2 if polity2==-5
replace polity_linear5=3 if polity2>-5 & polity2<0
replace polity_linear5=4 if polity2==0
replace polity_linear5=5 if polity2>0 & polity2<3
replace polity_linear5=6 if polity2==3
replace polity_linear5=7 if polity2>3
tab polity_linear5
} 

quietly{
gen polity_linear6=.
replace polity_linear6=1 if polity2<-5
replace polity_linear6=2 if polity2==-5
replace polity_linear6=3 if polity2>-5 & polity2<0
replace polity_linear6=4 if polity2==0
replace polity_linear6=5 if polity2>0 & polity2<3
replace polity_linear6=6 if polity2==3
replace polity_linear6=7 if polity2>3
tab polity_linear6
}


ologit physintflip Oil polity_linear1 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode)
ologit physintflip oil_gas_rentPOP polity_linear2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode)
ologit pts_a Oil polity_linear3 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag, cluster(ccode)
ologit pts_a oil_gas_rentPOP polity_linear4 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag, cluster(ccode)
ologit pts_s Oil polity_linear5 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag2, cluster(ccode)
ologit pts_s oil_gas_rentPOP polity_linear6 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag2, cluster(ccode)

*** Consider mixed regimes ***
* (1) Respecify with squared polity score
gen polity2sq=polity2*polity2
ologit physintflip Oil polity2 polity2sq gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode) nolog
ologit physintflip oil_gas_rentPOP polity2 polity2sq gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode) nolog
ologit pts_a Oil polity2 polity2sq gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag, cluster(ccode) nolog
ologit pts_a oil_gas_rentPOP polity2 polity2sq gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag, cluster(ccode) nolog
ologit pts_s Oil polity2 polity2sq gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag2, cluster(ccode) nolog
ologit pts_s oil_gas_rentPOP polity2 polity2sq gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag2, cluster(ccode) nolog

* (2) Respecify with three dummies replacing polity index: democ (polity>=6), autoc (polity<=-6), and mixed regimes (-6<polity<6).
* NOTE: Reference category is autocracy (dems should repress less, mixed regimes should repress more).
quietly{
gen democ_bin=.
replace democ_bin=1 if polity2>=6
replace democ_bin=0 if polity2<6
replace democ_bin=. if polity2==.
gen autoc_bin=.
replace autoc_bin=1 if polity2<=-6
replace autoc_bin=0 if polity2>-6
replace autoc_bin=. if polity2==.
gen mixed=1
replace mixed=0 if polity2<=-6
replace mixed=0 if polity2>=6
replace mixed=. if polity2==.
}

ologit physintflip Oil democ_bin mixed gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode) nolog
ologit physintflip oil_gas_rentPOP democ_bin mixed gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode) nolog
ologit pts_a Oil democ_bin mixed gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag, cluster(ccode) nolog
ologit pts_a oil_gas_rentPOP democ_bin mixed gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag, cluster(ccode) nolog
ologit pts_s Oil democ_bin mixed gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag2, cluster(ccode) nolog
ologit pts_s oil_gas_rentPOP democ_bin mixed gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag2, cluster(ccode) nolog

* (3) Use Vreeland's (2008) modified polity measure, both as-is and squared

quietly{
* NOTE: The following code comes from Vreeland's (2008) JCR replication file "table2.do" *
*********************************************************************************************************************
*FIRST recode polity components appropriately using codebook
/* xropen 
(1) Closed -1  (if xrcomp is Selection)
(2) Dual Executive -- Designation -1 (if xrcomp is Selection)
(3) Dual Executive -- Election +1 (if xrcomp is Election or Transitional)
(4) Open +1  (if xrcomp is Election or Transitional)  */
replace xropen=xropen*10
replace xropen=. if xropen==-660 | xropen==-770 | xropen==-880
replace xropen=-1 if xropen==10 & xrcomp==1
replace xropen=0 if xropen==10 & xrcomp~=1
replace xropen=-1 if xropen==20 & xrcomp==1
replace xropen=0 if xropen==20 & xrcomp~=1
replace xropen=1 if xropen==30 & xrcomp>1
replace xropen=0 if xropen==30 & xrcomp<2
replace xropen=1 if xropen==40 & xrcomp>1
replace xropen=0 if xropen==40 & xrcomp<2

/* xrcomp 
(1) Selection -2
(2) Dual/Transitional +1
(3) Election +2                 */
replace xrcomp=xrcomp*10
replace xrcomp=-2 if xrcomp==10
replace xrcomp=1 if xrcomp==20
replace xrcomp=2 if xrcomp==30
replace xrcomp=. if xrcomp==-660 | xrcomp==-770 | xrcomp==-880

/* xconst 
(1) Unlimited Authority -3
(2) Intermediate Category -2
(3) Slight to Moderate Limitations on Executive Authority -1
(4) Intermediate category 1
(5) Substantial Limitations on Executive Authority 2
(6) Intermediate Category 3
(7) Executive Parity | Subordination 4                 */
replace xconst=xconst*10
replace xconst=-3 if xconst==10
replace xconst=-2 if xconst==20
replace xconst=-1 if xconst==30
replace xconst=1 if xconst==40
replace xconst=2 if xconst==50
replace xconst=3 if xconst==60
replace xconst=4 if xconst==70
replace xconst=. if xconst==-660 | xconst==-770 | xconst==-880

/* parreg 
(1) Unregulated Participation 0
(2) Factional | Transitional 0
(3) Factional/Restricted -1
(4) Restricted -2
(5) Regulated 0                 */
replace parreg=parreg*10
replace parreg=0 if parreg==10
replace parreg=0 if parreg==20
replace parreg=-1 if parreg==30
replace parreg=-2 if parreg==40
replace parreg=0 if parreg==50
replace parreg=. if parreg==-660 | parreg==-770 | parreg==-880

/* parcomp
(1) Suppressed Competition -2
(2) Restricted/Transitional -1
(3) Factional Competition +1
(4) Transitional competition +2
(5) Competitive Competition +3
(00) Not Applicable 0                 */
replace parcomp=parcomp*10
replace parcomp=-2 if parcomp==10
replace parcomp=-1 if parcomp==20
replace parcomp=1 if parcomp==30
replace parcomp=2 if parcomp==40
replace parcomp=3 if parcomp==50
replace parcomp=0 if parcomp==0
replace parcomp=. if parcomp==-660 | parcomp==-770 | parcomp==-880

*create polity with only xconst, xropen, xrcomp (leave out parreg parcomp)
gen xpolity=xrcomp + xropen + xconst
replace xpolity=. if xrcomp==. | xropen==. | xconst==. 

*create squared terms:
gen xrcompsq=xrcomp*xrcomp
gen xropensq=xropen*xropen
gen xconstsq= xconst*xconst
gen parregsq= parreg*parreg
gen parcomsq=parcomp*parcomp
gen xpolitysq=xpolity*xpolity

sum xpolity xrcomp xropen xconst parreg parcomp
sum xpolitysq xrcompsq xropensq xconstsq parregsq parcomsq
*********************************************************************************************************************
* End Vreeland's (2008) code *
}
ologit physintflip Oil xpolity xpolitysq gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode) nolog
ologit physintflip oil_gas_rentPOP xpolity xpolitysq gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode) nolog
ologit pts_a Oil xpolity xpolitysq gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag, cluster(ccode) nolog
ologit pts_a oil_gas_rentPOP xpolity xpolitysq gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag, cluster(ccode) nolog
ologit pts_s Oil xpolity xpolitysq gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag2, cluster(ccode) nolog
ologit pts_s oil_gas_rentPOP xpolity xpolitysq gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag2, cluster(ccode) nolog


*** interact democratic institutions with dissent ***
*NOTE: Following Davenport (2007), we interact:
	
	*(1) political competition with civil war [p169]
gen polcomp_civwar=polcomp*civwar_bin
ologit physintflip Oil polcomp civwar_bin polcomp_civwar gdpenl jobinsecurity_bdm lpop diss_lag lmtnest physint_lag, cluster(ccode) nolog
ologit physintflip oil_gas_rentPOP polcomp civwar_bin polcomp_civwar gdpenl jobinsecurity_bdm lpop diss_lag lmtnest physint_lag, cluster(ccode) nolog
ologit pts_a Oil polcomp civwar_bin polcomp_civwar gdpenl jobinsecurity_bdm lpop diss_lag lmtnest repression_lag, cluster(ccode) nolog
ologit pts_a oil_gas_rentPOP polcomp civwar_bin polcomp_civwar gdpenl jobinsecurity_bdm lpop diss_lag lmtnest repression_lag, cluster(ccode) nolog
ologit pts_s Oil polcomp civwar_bin polcomp_civwar gdpenl jobinsecurity_bdm lpop diss_lag lmtnest repression_lag2, cluster(ccode) nolog
ologit pts_s oil_gas_rentPOP polcomp civwar_bin polcomp_civwar gdpenl jobinsecurity_bdm lpop diss_lag lmtnest repression_lag2, cluster(ccode) nolog

	*(2) executive constraints with civil war (yes/no) [p. 157]
gen exconst_civwar=exconst*civwar_bin
ologit physintflip Oil exconst civwar_bin exconst_civwar gdpenl jobinsecurity_bdm lpop diss_lag lmtnest physint_lag, cluster(ccode) nolog
ologit physintflip oil_gas_rentPOP exconst civwar_bin exconst_civwar gdpenl jobinsecurity_bdm lpop diss_lag lmtnest physint_lag, cluster(ccode) nolog
ologit pts_a Oil exconst civwar_bin exconst_civwar gdpenl jobinsecurity_bdm lpop diss_lag lmtnest repression_lag, cluster(ccode) nolog
ologit pts_a oil_gas_rentPOP exconst civwar_bin exconst_civwar gdpenl jobinsecurity_bdm lpop diss_lag lmtnest repression_lag, cluster(ccode) nolog
ologit pts_s Oil exconst civwar_bin exconst_civwar gdpenl jobinsecurity_bdm lpop diss_lag lmtnest repression_lag2, cluster(ccode) nolog
ologit pts_s oil_gas_rentPOP exconst civwar_bin exconst_civwar gdpenl jobinsecurity_bdm lpop diss_lag lmtnest repression_lag2, cluster(ccode) nolog

	*(3) a combination of the two with civil war [p. 169]
gen exconst_polcom_civwar=exconst*polcomp*civwar_bin
ologit physintflip Oil polcomp exconst civwar_bin exconst_polcom_civwar gdpenl jobinsecurity_bdm lpop diss_lag lmtnest physint_lag, cluster(ccode) nolog
ologit physintflip oil_gas_rentPOP polcomp exconst civwar_bin exconst_polcom_civwar gdpenl jobinsecurity_bdm lpop diss_lag lmtnest physint_lag, cluster(ccode) nolog
ologit pts_a Oil polcomp exconst civwar_bin exconst_polcom_civwar gdpenl jobinsecurity_bdm lpop diss_lag lmtnest repression_lag, cluster(ccode) nolog
ologit pts_a oil_gas_rentPOP polcomp exconst civwar_bin exconst_polcom_civwar gdpenl jobinsecurity_bdm lpop diss_lag lmtnest repression_lag, cluster(ccode) nolog
ologit pts_s Oil polcomp exconst civwar_bin exconst_polcom_civwar gdpenl jobinsecurity_bdm lpop diss_lag lmtnest repression_lag2, cluster(ccode) nolog
ologit pts_s oil_gas_rentPOP polcomp exconst civwar_bin exconst_polcom_civwar gdpenl jobinsecurity_bdm lpop diss_lag lmtnest repression_lag2, cluster(ccode) nolog

*****Interact oil and democracy explicitly (a la BdM and Smith 2009)
gen oil_x_democ=Oil*polity2
gen fuel_x_democ=oil_gas_rentPOP*polity2

ologit physintflip Oil polity2 oil_x_democ gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode) nolog
ologit physintflip oil_gas_rentPOP polity2 fuel_x_democ gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode) nolog
ologit pts_a Oil polity2 oil_x_democ gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag, cluster(ccode) nolog
ologit pts_a oil_gas_rentPOP polity2 fuel_x_democ gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag, cluster(ccode) nolog
ologit pts_s Oil polity2 oil_x_democ gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag2, cluster(ccode) nolog
ologit pts_s oil_gas_rentPOP polity2 fuel_x_democ gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag2, cluster(ccode) nolog

********************************
* INTERNATIONAL FACTORS
********************************
*** International Law ***
*NOTE: Treaty ratification data come from Neumayer (2005), and include (for our use):
	*ICCPR ratification, ratifying the first ICCPR optional protocol, CAT ratification, and ratifying articles 21 & 22 of the CAT.
	
* Bivariate correlations of international law with oil exports and fuel rents, and repression:	
corr Oil oil_gas_rentPOP physintflip pts_a pts_s iccprmainrat iccproptrat torturerat tortureart2122rat

* Add international law to main model specification (focusing only on CIRI because enough is enough, srsly):
** ICCPR:
ologit physintflip Oil iccprmainrat polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode) nolog
ologit physintflip oil_gas_rentPOP iccprmainrat polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode) nolog
** ICCPR Optional Protocol:
ologit physintflip Oil iccproptrat polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode) nolog
ologit physintflip oil_gas_rentPOP iccproptrat polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode) nolog
** CAT:
ologit physintflip Oil torturerat polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode) nolog
ologit physintflip oil_gas_rentPOP torturerat polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode) nolog
** CAT articles 21 & 22:
ologit physintflip Oil tortureart2122rat polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode) nolog
ologit physintflip oil_gas_rentPOP tortureart2122rat polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode) nolog


*** International Advocacy Campaigns ***
	
	
	
********************************
* OTHER ROBUSTNESS CHECKS
********************************

*** Control for MidEast States = oil produces, repressors ***

* Control via North Africa/MidEast Dummy:
ologit physintflip Oil polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag nafrme, nolog robust
ologit physintflip oil_gas_rentPOP polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag nafrme, nolog robust
ologit pts_a Oil polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag nafrme, nolog robust
ologit pts_a oil_gas_rentPOP polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag nafrme, nolog robust
ologit pts_s Oil polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag2 nafrme, nolog robust
ologit pts_s oil_gas_rentPOP polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag2 nafrme, nolog robust

*** Control for % Muslim Population ***
ologit physintflip Oil polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag muslim, cluster(ccode)
ologit physintflip oil_gas_rentPOP polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag muslim, cluster(ccode)
ologit pts_a Oil polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag muslim, cluster(ccode)
ologit pts_a oil_gas_rentPOP polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag muslim, cluster(ccode)
ologit pts_s Oil polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag2 muslim, cluster(ccode)
ologit pts_s oil_gas_rentPOP polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest repression_lag2 muslim, cluster(ccode)

*** Consider International Factors (International Law) ***
	*NOTE: Treaty ratification data come from Neumayer (2005), and include (for our use):
		*ICCPR ratification, ratifying the first ICCPR optional protocol, CAT ratification, and ratifying articles 21 & 22 of the CAT.
	
* Bivariate correlations of international law with oil exports and fuel rents, and repression:	
corr Oil oil_gas_rentPOP physintflip pts_a pts_s iccprmainrat iccproptrat torturerat tortureart2122rat

* Add international law to main model specification (focusing only on CIRI because enough is enough, srsly):
** ICCPR:
ologit physintflip Oil iccprmainrat polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode) nolog
ologit physintflip oil_gas_rentPOP iccprmainrat polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode) nolog

** ICCPR Optional Protocol:
ologit physintflip Oil iccproptrat polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode) nolog
ologit physintflip oil_gas_rentPOP iccproptrat polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode) nolog

** CAT:
ologit physintflip Oil torturerat polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode) nolog
ologit physintflip oil_gas_rentPOP torturerat polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode) nolog

** CAT articles 21 & 22:
ologit physintflip Oil tortureart2122rat polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode) nolog
ologit physintflip oil_gas_rentPOP tortureart2122rat polity2 gdpenl jobinsecurity_bdm lpop diss_lag cowwarl lmtnest physint_lag, cluster(ccode) nolog


log close
